@@ -7,7 +7,7 @@ import time
 import threading
 import datetime
 import multiprocessing
-from Database import TasksDatabase as database
+from pg_tasks_queue.Database import TasksDatabase as database
 
 
 class Worker(object):
